@@ -27,8 +27,8 @@ class BankAccountsApi(BaseApi):
                 previous call to this endpoint. Use it in the next
                 `ListBankAccounts` request to retrieve the next set  of
                 results.  See the
-                [Pagination](https://developer.squareup.com/docs/docs/working-w
-                ith-apis/pagination) guide for more information.
+                [Pagination](https://developer.squareup.com/docs/working-with-a
+                pis/pagination) guide for more information.
             limit (int, optional): Upper limit on the number of bank accounts
                 to return in the response.  Currently, 1000 is the largest
                 supported limit. You can specify a limit  of up to 1000 bank
@@ -93,9 +93,9 @@ class BankAccountsApi(BaseApi):
             v1_bank_account_id (string): Connect V1 ID of the desired
                 `BankAccount`. For more information, see  [Retrieve a bank
                 account by using an ID issued by V1 Bank Accounts
-                API](https://developer.squareup.com/docs/docs/bank-accounts-api
-                #retrieve-a-bank-account-by-using-an-id-issued-by-v1-bank-accou
-                nts-api).
+                API](https://developer.squareup.com/docs/bank-accounts-api#retr
+                ieve-a-bank-account-by-using-an-id-issued-by-v1-bank-accounts-a
+                pi).
 
         Returns:
             ApiResponse: An object with the response value as well as other
