@@ -198,8 +198,8 @@ class InvoicesApi(BaseApi):
         Deletes the specified invoice. When an invoice is deleted, the 
         associated Order status changes to CANCELED. You can only delete a
         draft 
-        invoice (you cannot delete an invoice scheduled for publication, or a
-                published invoice).
+        invoice (you cannot delete a published invoice, including one that is
+        scheduled for processing).
 
         Args:
             invoice_id (string): The ID of the invoice to delete.
@@ -308,14 +308,17 @@ class InvoicesApi(BaseApi):
                        body):
         """Does a PUT request to /v2/invoices/{invoice_id}.
 
-        Updates an invoice by modifying field values, clearing field values,
-        or both 
-        as specified in the request. 
-        There are no restrictions to updating an invoice in a draft state. 
-        However, there are guidelines for updating a published invoice.
+        Updates an invoice by modifying fields, clearing fields, or both. For
+        most updates, you can use a sparse 
+        `Invoice` object to add fields or change values, and use the
+        `fields_to_clear` field to specify fields to clear. 
+        However, some restrictions apply. For example, you cannot change the
+        `order_id` or `location_id` field, and you 
+        must provide the complete `custom_fields` list to update a custom
+        field. Published invoices have additional restrictions.
 
         Args:
-            invoice_id (string): The id of the invoice to update.
+            invoice_id (string): The ID of the invoice to update.
             body (UpdateInvoiceRequest): An object containing the fields to
                 POST for the request.  See the corresponding object definition
                 for field details.
